@@ -6,7 +6,8 @@ from pikepdf import Pdf
 @pytest.fixture
 def vera(resources):
     # A file that is not linearized
-    return Pdf.open(resources / 'veraPDF test suite 6-2-10-t02-pass-a.pdf')
+    with Pdf.open(resources / 'veraPDF test suite 6-2-10-t02-pass-a.pdf') as pdf:
+        yield pdf
 
 
 def test_foreign_linearization(vera):
