@@ -15,7 +15,8 @@ from pikepdf import Pdf, PdfError
 @pytest.fixture
 def sandwich(resources):
     # Has XMP, docinfo, <?adobe-xap-filters esc="CRLF"?>, shorthand attribute XMP
-    return Pdf.open(resources / 'sandwich.pdf')
+    with Pdf.open(resources / 'sandwich.pdf') as pdf:
+        yield pdf
 
 
 class LimitedBytesIO(BytesIO):
@@ -99,12 +100,8 @@ def file_descriptor_is_open_for():
         pytest.skip(
             "psutil documentation warns that .open_files() has problems on these"
         )
-    elif (
-        sys.platform == 'linux'
-        and sys.version_info < (3, 7)
-        and sys.implementation.name == 'pypy'
-    ):
-        pytest.xfail("for reasons not entirely clear, this test fails")
+    elif sys.implementation.name == 'pypy':
+        pytest.skip("randomly fails on pypy")
 
     def _file_descriptor_is_open_for(path):
         process = psutil.Process()
@@ -226,3 +223,19 @@ def test_save_bytesio(resources, outpdf):
         assert bio_value != b''
         pdf.save(outpdf, static_id=True)
         assert outpdf.read_bytes() == bio_value
+
+
+@pytest.mark.skipif(
+    hasattr(os, 'geteuid') and os.geteuid() == 0, reason="root can override permissions"
+)
+def test_save_failure(sandwich, outdir):
+    dest = outdir / 'notwritable.pdf'
+
+    # This should work on Windows since Python maps the read-only bit
+    dest.touch(mode=0o444, exist_ok=False)
+    if dest.stat().st_mode & 0o400 != 0o400:
+        pytest.skip("Couldn't create a read-only file")
+
+    # Now try to overwrite
+    with pytest.raises(PermissionError, match="denied"):
+        sandwich.save(dest)
