@@ -275,11 +275,13 @@ def test_concatenate(resources, outdir):
 
 def test_emplace(fourpages):
     p0_objgen = fourpages.pages[0].objgen
+    fourpages.pages[0].SpecialKey = "This string will be deleted"
     fourpages.pages[0].emplace(fourpages.pages[1])
     assert p0_objgen == fourpages.pages[0].objgen
     assert fourpages.pages[0].keys() == fourpages.pages[1].keys()
     for k in fourpages.pages[0].keys():
         assert fourpages.pages[0][k] == fourpages.pages[1][k]
+    assert Name.SpecialKey not in fourpages.pages[0]
 
 
 def test_emplace_foreign(fourpages, sandwich):
@@ -327,6 +329,16 @@ def test_add_foreign_twice(graph, outpdf):
     out.save(outpdf)
 
 
+@pytest.mark.xfail(reason="needs qpdf fix to issue 514")
+def test_add_twice_without_copy_foreign(graph, outpdf):
+    out = Pdf.new()
+    out.pages.append(graph.pages[0])
+    assert len(out.pages) == 1
+    out.pages.append(graph.pages[0])
+    assert len(out.pages) == 2
+    out.save(outpdf)
+
+
 def test_repr_pagelist(fourpages):
     assert '4' in repr(fourpages.pages)
 
